@echo off

REM All variable definitions herein are 'local'
setlocal

REM *** DETERMINE MICROSOFT COMPILER VERSION
set MSV=0
cl 2>&1 | findstr /i /r Version.13\. > nul
if %ERRORLEVEL%==0 set MSV=13
cl 2>&1 | findstr /i /r Version.14\. > nul
if %ERRORLEVEL%==0 set MSV=14
cl 2>&1 | findstr /i /r Version.15\. > nul
if %ERRORLEVEL%==0 set MSV=15
cl 2>&1 | findstr /i /r Version.16\. > nul
if %ERRORLEVEL%==0 set MSV=16
cl 2>&1 | findstr /i /r Version.17\. > nul
if %ERRORLEVEL%==0 set MSV=17
cl 2>&1 | findstr /i /r Version.18\. > nul
if %ERRORLEVEL%==0 set MSV=18
if %MSV%==0 goto unknown_compiler

REM *** DETERMINE IF 64BIT COMPILER
set MSV64=0
cl 2>&1 | findstr /i /r for.x64
if %ERRORLEVEL%==0 set MSV64=1

echo.
echo      *** FLTK CONFIGURATION ***
echo.

if %MSV64%==1 echo        64bit compiler detected
if %MSV64%==1 echo.

REM ***
REM *** DEBUG/INSURE++/RELEASE
REM ***
    if defined DEBUG goto debug_defined
    :debug_prompt
    set DEBUG=
    set USE_INSURE=0
    set /P DEBUG=     Build Mode: D)ebug or I)nsure++ or R)elease? [R] 
    IF NOT DEFINED DEBUG set DEBUG=R
    IF %DEBUG%==r set DEBUG=R
    IF %DEBUG%==d set DEBUG=D
    IF %DEBUG%==i set USE_INSURE=1
    IF %DEBUG%==i set DEBUG=D
    IF %DEBUG%==I set USE_INSURE=1
    IF %DEBUG%==I set DEBUG=D
    IF %DEBUG%==R goto debug_defined
    IF %DEBUG%==D goto debug_defined
    goto debug_prompt
    :debug_defined

REM ***
REM *** VERBOSE/QUIET
REM ***
    if defined VERBOSE goto verbose_defined
    :verbose_prompt
    set VERBOSE=
    set /P VERBOSE=Build Verbosity: V)erbose or Q)uiet? [Q] 
    IF NOT DEFINED VERBOSE set VERBOSE=Q
    IF %VERBOSE%==v set VERBOSE=V
    IF %VERBOSE%==q set VERBOSE=Q
    IF %VERBOSE%==V goto verbose_defined
    IF %VERBOSE%==Q goto verbose_defined
    goto verbose_prompt
    :verbose_defined

    echo.

REM ***
REM *** INSTALL MAKEFILES
REM ***

    echo === installing makefiles ===
    echo *** TOP
    copy buildtools.windows\Makefiles\Makefile.MICROSOFT         .
    copy buildtools.windows\Makefiles\gmake-vsnet-include.v%MSV% .\gmake-vsnet-include

    echo *** SRC
    copy buildtools.windows\Makefiles\src\Makefile.MICROSOFT    src
    copy buildtools.windows\Makefiles\src\gmake.bat             src
    copy buildtools.windows\Makefiles\src\gmake-fltk-include    src

    echo *** JPEG
    copy buildtools.windows\Makefiles\jpeg\Makefile.MICROSOFT   jpeg
    copy buildtools.windows\Makefiles\src\gmake.bat             jpeg

    echo *** PNG
    copy buildtools.windows\Makefiles\png\Makefile.MICROSOFT    png
    copy buildtools.windows\Makefiles\src\gmake.bat             png

    echo *** ZLIB
    copy buildtools.windows\Makefiles\zlib\Makefile.MICROSOFT   zlib
    copy buildtools.windows\Makefiles\src\gmake.bat             zlib

    echo *** FLUID
    copy buildtools.windows\Makefiles\fluid\Makefile.MICROSOFT  fluid
    copy buildtools.windows\Makefiles\src\gmake.bat             fluid

    echo *** TEST
    copy buildtools.windows\Makefiles\test\Makefile.MICROSOFT   test
    copy buildtools.windows\Makefiles\src\gmake.bat             test

    echo *** EXAMPLES
    copy buildtools.windows\Makefiles\examples\Makefile.MICROSOFT examples
    copy buildtools.windows\Makefiles\src\gmake.bat               examples


REM ***
REM *** CREATE CONFIG FILE
REM ***
    echo.
    echo === creating configure files ===
    echo # Created by 'gmake configure' on %DATE% %TIME% > gmake-configure-include
    echo.>>                                  gmake-configure-include
    echo # DEBUG>>                           gmake-configure-include
    if %DEBUG%==R echo FLTKDEBUG=0 >>        gmake-configure-include
    if %DEBUG%==D echo FLTKDEBUG=1 >>        gmake-configure-include
    echo.>>                                  gmake-configure-include
    echo # INSURE>>                          gmake-configure-include
    if %USE_INSURE%==0 echo USE_INSURE=0 >>  gmake-configure-include
    if %USE_INSURE%==1 echo USE_INSURE=1 >>  gmake-configure-include
    echo.>>                                  gmake-configure-include
    echo # VERBOSE>>                         gmake-configure-include
    if %VERBOSE%==V echo # .SILENT:>>        gmake-configure-include
    if %VERBOSE%==Q echo .SILENT:>>          gmake-configure-include
    echo.>>                                  gmake-configure-include
    echo # FLTK TOP LEVEL DIR>>              gmake-configure-include
    echo FLTKTOPDIR=%CD%>>                   gmake-configure-include
    echo.>>                                  gmake-configure-include
    echo # MS COMPILER VERSION: %MSV%>>      gmake-configure-include
    echo.>>                                  gmake-configure-include
    echo # 64bit? >>                         gmake-configure-include
    if %MSV64%==0 echo MSV64=0 >>            gmake-configure-include
    if %MSV64%==1 echo MSV64=1 >>            gmake-configure-include
    echo.>>                                  gmake-configure-include
    echo # DISABLE STUPID CYGWIN WARNINGS>>  gmake-configure-include
    echo CYGWIN=nodosfilewarning>>           gmake-configure-include

REM ***
REM *** CREATE CONFIG.H FILE
REM ***
    echo.
    echo === creating config.h ===
    echo # Copying from vcnet directory
    REM copy /Y vcnet\config.h .                # OLD LOCATION
    REM copy /Y ide\vc2005\config.h .           # OLD LOCATION
    copy /Y ide\visualc6\config.h .

REM ***
REM *** MAKE SURE .fl FILES ARE NOT NEWER THAN .cxx
REM ***     Otherwise fluid.exe will be called to make .cxx files
REM ***     before the library is even built.
REM ***
    echo.
    echo === Fixing date stamps to prevent invoking fluid before its built ===
    cd src   && call gmake.bat --touch Fl_File_Chooser.cxx && cd ..
    cd src   && call gmake.bat --touch Fl_Help_Dialog.cxx  && cd ..
    cd fluid && call gmake.bat --touch about_panel.cxx     && cd ..
    cd fluid && call gmake.bat --touch alignment_panel.cxx && cd ..
    cd fluid && call gmake.bat --touch function_panel.cxx  && cd ..
    cd fluid && call gmake.bat --touch template_panel.cxx  && cd ..
    cd fluid && call gmake.bat --touch widget_panel.cxx    && cd ..
    cd fluid && call gmake.bat --touch print_panel.cxx     && cd ..

REM ***
REM *** DONE
REM ***
    echo.
    echo *** CONFIGURED. You can now rebuild fltk with:
    echo.
    echo         gmake clean
    echo         gmake
    echo.
goto done

:unknown_compiler
    echo ERROR: Unknown MS compiler version:
    cl 2>&1 | findstr /i /r Version

:done
